from functools import partial


rule annotate_normcounts:
    input:
        counts="results/expression/{model}/{paramspace_instance}.norm.filtered.tsv",
        ann="resources/filtered-annotation/{model}/{paramspace_instance}.csv",
        diffexp="results/differential_expression/{model}/{paramspace_instance}.annotated.{diffexp_filter}.tsv",
    output:
        "results/expression/{model}/{paramspace_instance}.norm.annotated.{diffexp_filter}.tsv"
    params:
        model=get_model,
    log:
        "logs/annotate_normcounts/{model}/{paramspace_instance}/{diffexp_filter}.log"
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/annotate_normcounts.py"


rule render_differential_logfc_plot_spec:
    input:
        workflow.source_path("../resources/differential_logfc_plot_spec.json.j2"),
    output:
        "resources/datavzrd/{model}/{paramspace_instance}/differential_logfc_plot_spec.json"
    params:
        other_paramspace_instance_descriptors=get_other_paramspace_instance_descriptors,
    template_engine:
        "jinja2"


rule render_diffexp_datavzrd_config:
    input:
        template=workflow.source_path("../resources/diffexp.datavzrd.yaml"),
        diffexp="results/differential_expression/{model}/{paramspace_instance}.annotated.{diffexp_filter}.tsv",
        normcounts="results/expression/{model}/{paramspace_instance}.norm.annotated.{diffexp_filter}.tsv",
        ann="resources/filtered-annotation/{model}/{paramspace_instance}.csv",
        differential_logfc_plot=get_differential_logfc_plot,
    output:
        "resources/datavzrd/diffexp/{model}/{paramspace_instance}/{diffexp_filter}.yaml"
    params:
        model=get_model,
    template_engine:
        "yte"


rule datavzrd_diffexp:
    input:
        config="resources/datavzrd/diffexp/{model}/{paramspace_instance}/{diffexp_filter}.yaml",
        table="results/differential_expression/{model}/{paramspace_instance}.annotated.{diffexp_filter}.tsv",
        normcounts="results/expression/{model}/{paramspace_instance}.norm.annotated.{diffexp_filter}.tsv",
    output:
        report(
            directory("results/datavzrd/diffexp/{model}/{paramspace_instance}/{diffexp_filter}"),
            htmlindex="index.html",
            # see https://snakemake.readthedocs.io/en/stable/snakefiles/reporting.html
            # for additional options like caption, categories and labels
            category="Differential expression analysis",
            subcategory="{model}",
            labels=lambda w, input: get_report_labels_with_n_significant(w, input, include_model=False),
            caption="../report/diffexp.rst",
        ),
    params:
        model=get_model,
        diffexp_query=get_diffexp_query,
    log:
        "logs/datavzrd/diffexp/{model}/{paramspace_instance}/{diffexp_filter}.log",
    wrapper:
        "v3.0.2/utils/datavzrd"


rule render_enrichment_datavzrd_config:
    input:
        template=workflow.source_path("../resources/enrichment.datavzrd.yaml"),
        enrichment="results/gsea/{model}/{paramspace_instance}/{diffexp_filter}/{enrichr_library}.tsv",
    output:
        "resources/datavzrd/enrichment/{model}/{paramspace_instance}/{diffexp_filter}/{enrichr_library}.yaml"
    params:
        paramspace_instance=get_paramspace_instance,
    template_engine:
        "yte"


use rule datavzrd_diffexp as datavzrd_enrichment with:
    input:
        config="resources/datavzrd/enrichment/{model}/{paramspace_instance}/{diffexp_filter}/{enrichr_library}.yaml",
        table="results/gsea/{model}/{paramspace_instance}/{diffexp_filter}/{enrichr_library}.tsv",
    output:
        report(
            directory("results/datavzrd/enrichment/{model}/{paramspace_instance}/{diffexp_filter}/{enrichr_library}"),
            htmlindex="index.html",
            category="Enrichment analysis",
            subcategory="{enrichr_library}",
            labels=get_report_labels_with_n_significant,
            caption="../report/enrichment.rst",
        ),
    log:
        "logs/datavzrd/enrichment/{model}/{paramspace_instance}/{diffexp_filter}/{enrichr_library}.log"

rule render_qc_table_datavzrd_config:
    input:
        template=workflow.source_path("../resources/nanotube_qc_table.datavzrd.yaml"),
        qc_table="results/expression/{model}/{paramspace_instance}.qc_table.tsv",
    output:
        "resources/datavzrd/qc_table/{model}/{paramspace_instance}.qc_table.yaml",
    params:
        paramspace_instance=get_paramspace_instance,
    template_engine:
        "yte"


use rule datavzrd_diffexp as datavzrd_qc_table with:
    input:
        config="resources/datavzrd/qc_table/{model}/{paramspace_instance}.qc_table.yaml",
        table="results/expression/{model}/{paramspace_instance}.qc_table.tsv",
    output:
        report(
            directory("results/datavzrd/qc_table/{model}/{paramspace_instance}/"),
            htmlindex="index.html",
            category="Quality control",
            subcategory="NanoTube metrics table",
            labels=get_report_labels,
            caption="../report/nanotube_qc_table.rst",
        ),
    log:
        "logs/datavzrd/qc_table/{model}/{paramspace_instance}.qc_table.log",