rule diffexp:
    input:
        counts="results/expression/{model}/{paramspace_instance}.norm.filtered.tsv",
        samples="resources/filtered-annotation/{model}/{paramspace_instance}.csv",
    output:
        dgelist="results/differential_expression/{model}/{paramspace_instance}.norm.rds",
        diffexp_table="results/differential_expression/{model}/{paramspace_instance}.raw.tsv",
        bcv=report(
            "results/plots/qc/diffexp/{model}/{paramspace_instance}.bcv.pdf",
            category="Quality control",
            subcategory="coefficient of variation analysis",
            labels=get_report_labels,
            caption="../report/bcv.rst",
        ),
        md=report(
            "results/plots/qc/diffexp/{model}/{paramspace_instance}.md.pdf",
            category="Quality control",
            subcategory="mean-difference analysis",
            labels=get_report_labels,
            caption="../report/md.rst",
        ),
        disp=report(
            "results/plots/qc/diffexp/{model}/{paramspace_instance}.disp.pdf",
            category="Quality control",
            subcategory="dispersion analysis",
            labels=get_report_labels,
            caption="../report/dispersion.rst",
        ),
    log:
        "logs/differential_expression/{model}/{paramspace_instance}.log"
    conda:
        "../envs/edger.yaml"
    params:
        model=get_model,
    script:
        "../scripts/diffexp.R"


rule annotate_diffexp:
    input:
        diffexp="results/differential_expression/{model}/{paramspace_instance}.raw.tsv",
        other_paramspace_instance_diffexp=get_other_paramspace_instance_diffexp,
    output:
        "results/differential_expression/{model}/{paramspace_instance}.annotated.nofilter.tsv"
    params:
        other_paramspace_instance_descriptors=get_other_paramspace_instance_descriptors,
        model=get_model,
    log:
        "logs/annotate_diffexp/{model}/{paramspace_instance}.log"
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/annotate_diffexp.py"


rule filter_diffexp:
    input:
        "results/differential_expression/{model}/{paramspace_instance}.annotated.nofilter.tsv"
    output:
        "results/differential_expression/{model}/{paramspace_instance}.annotated.{diffexp_filter}.tsv"
    log:
        "logs/filter_diffexp/{model}/{paramspace_instance}/{diffexp_filter}.log"
    params:
        diffexp_query=get_diffexp_query,
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/filter_diffexp.py"


ruleorder: annotate_diffexp > filter_diffexp