rule prepare_annotation:
    output:
        ann="resources/annotation/{model}/{paramspace_instance}.csv",
    log:
        "logs/annotation/{model}/{paramspace_instance}.log"
    params:
        samples=samples,
        paramspace_instance=get_paramspace_instance,
    run:
        import os
        annotation = select_samples(params.paramspace_instance, params.samples)
        annotation.loc[:, "rcc"] = annotation["rcc"].apply(os.path.basename)
        annotation.to_csv(output[0], sep=",", index=False)


rule symlink_rcc_files:
    input:
        get_raw_rcc_file_path,
    output:
        temp("resources/rccs/{model}/{paramspace_instance}/{file}"),
    log:
        "logs/rcc_symlinks/{model}/{paramspace_instance}/{file}.log"
    shell:
        # the number of ../ need to match the depth of the
        # output: path
        "(ln -r -s {input} {output}) 2> {log}"


rule normalize:
    """
    The resulting files contains a NanoStringRccSet, with both the
    exprs values and the exprs_norm values. The latter are only for
    quality control plots.
    """
    input:
        rccs=get_paramspace_instance_rcc_files,
        pheno_data="resources/annotation/{model}/{paramspace_instance}.csv",
    output:
        norm_counts_matrix="results/expression/{model}/{paramspace_instance}.norm.tsv",
        exprs_and_norm="results/expression/{model}/{paramspace_instance}.raw_and_norm.tsv",
        qc_table="results/expression/{model}/{paramspace_instance}.qc_table.tsv",
        rle_plot=report(
            "results/plots/{model}/{paramspace_instance}.rle_plot.pdf",
            category="Quality control",
            subcategory="relative log expression",
            labels=get_report_labels,
            caption="../report/relative_log_expression.rst",
        ),
    log:
        "logs/normalize/{model}/{paramspace_instance}.log"
    params:
        input_folder=lambda wc, input: path.dirname(input.rccs[0]),
        model=get_model,
    conda:
        "../envs/nano_tube.yaml"
    script:
        "../scripts/normalize.R"


rule exclude_replicates_and_dropout_samples:
    input:
        counts="results/expression/{model}/{paramspace_instance}.norm.tsv",
        ann="resources/annotation/{model}/{paramspace_instance}.csv",
    output:
        counts="results/expression/{model}/{paramspace_instance}.norm.filtered.tsv",
        ann="resources/filtered-annotation/{model}/{paramspace_instance}.csv",
        plt=report(
            "results/plots/qc/{model}/{paramspace_instance}.dist_and_filtering.html",
            category="Quality control",
            subcategory="expression distribution and filtering",
            labels=get_report_labels,
            caption="../report/expression_dist_and_filtering.rst",
        )
    params:
        min_fraction_nonzero=config["preprocessing"]["min_fraction_nonzero"],
    log:
        "logs/exclude_replicates_and_dropout_samples/{model}/{paramspace_instance}.log"
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/exclude_samples.py"