rule calc_mds:
    input:
        "results/expression/{model}/{paramspace_instance}.norm.tsv",
    output:
        "results/mds/{model}/{paramspace_instance}.mds.tsv"
    log:
        "logs/calc_mds/{model}/{paramspace_instance}.log"
    conda:
        "../envs/edger.yaml"
    script:
        "../scripts/calc_mds.R"


rule plot_mds:
    input:
        mds="results/mds/{model}/{paramspace_instance}.mds.tsv",
        ann="resources/annotation/{model}/{paramspace_instance}.csv",
    output:
        mds=report(
            "results/plots/clustering/{model}/{paramspace_instance}.mds.html",
            category="Quality control",
            subcategory="multidimensional scaling",
            labels=get_report_labels,
            caption="../report/mds.rst",
        )
    log:
        "logs/plot_mds/{model}/{paramspace_instance}.log"
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/plot_mds.py"


rule plot_exprs_and_norm:
    input:
        "results/expression/{model}/{paramspace_instance}.raw_and_norm.tsv",
    output:
        report(
            "results/plots/qc/{model}/{paramspace_instance}.raw_and_norm.html",
            category="Quality control",
            subcategory="normalization effect analysis",
            labels=get_report_labels,
            caption="../report/raw_and_norm.rst",
        ),
    log:
        "logs/plot_norm_qc/{model}/{paramspace_instance}.log"
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/plot_exprs_raw_and_norm.py"


rule plot_replicates:
    input:
        counts="results/expression/{model}/{paramspace_instance}.norm.tsv",
        ann="resources/annotation/{model}/{paramspace_instance}.csv",
    output:
        report(
            "results/plots/qc/{model}/{paramspace_instance}.replicates.html",
            category="Quality control",
            subcategory="replicate concordance",
            labels=get_report_labels,
            caption="../report/replicate_concordance.rst",
        ),
    log:
        "logs/plot_replicates/{model}/{paramspace_instance}.log",
    conda:
        "../envs/pystats.yaml"
    script:
        "../scripts/plot_replicates.py"