import sys

sys.stderr = open(snakemake.log[0], "w")

import pandas as pd

diffexp = pd.read_csv(snakemake.input[0], sep="\t", index_col="accession")

if snakemake.params.model.get("add_other_logfcs", False):
    logfc_loc = diffexp.columns.get_loc("logFC")
    fdr_loc = diffexp.columns.get_loc("FDR")

    for other_descriptor, other_diffexp in sorted(
        zip(snakemake.params.other_paramspace_instance_descriptors, snakemake.input.other_paramspace_instance_diffexp)
    ):
        other_diffexp = pd.read_csv(other_diffexp, sep="\t", index_col="accession")

        # FDR of other instance
        diffexp.insert(fdr_loc + 1, f"FDR_{other_descriptor}", other_diffexp["FDR"])

        # p-value of other instance
        diffexp.insert(fdr_loc + 1, f"pvalue_{other_descriptor}", other_diffexp["pvalue"])

        # diff_score is the difference in logFC, but with the sign flipped if the two are in opposite directions
        different_sign = (diffexp["logFC"] * other_diffexp["logFC"]) < 0
        factor = different_sign.map(lambda is_different_sign: -1 if is_different_sign else 1)
        diffexp.insert(
            logfc_loc + 1, 
            f"diff_score_{other_descriptor}", 
            (other_diffexp["logFC"] - diffexp["logFC"]).abs() * factor
        )

        # logFC of other instance
        diffexp.insert(logfc_loc + 1, f"logFC_{other_descriptor}", other_diffexp["logFC"])

diffexp.to_csv(snakemake.output[0], sep="\t")