import sys

sys.stderr = open(snakemake.log[0], "w")

import pandas as pd

counts = pd.read_csv(snakemake.input["counts"], sep="\t")
sample_cols = counts.columns[3:]

# discard decimals
counts.loc[:, sample_cols] = counts.loc[:, sample_cols].round(0).applymap(lambda v: int(v) if not pd.isna(v) else pd.NA)

# sort the same as diffexp, they are irrelevant for displaying the matrix
diffexp_order = pd.read_csv(snakemake.input["diffexp"], sep="\t")["accession"]
counts = counts.set_index("accession").reindex(diffexp_order).reset_index()

samples = pd.read_csv(snakemake.input["ann"], index_col="sample_name", dtype=str)

model = snakemake.params.model

# add annotation columns
precols = [(pre,) + ("", ) * len(model["annotation_cols"]) for pre in counts.columns[:3]]
samplecols = list(
    samples.loc[
        counts.columns[3:], model["annotation_cols"]
    ].fillna(
        "" # replace NAs with "" in order to be able to distinguish them when doing the sorting below
    ).reset_index(names="sample_name").itertuples(index=False)
)
counts.columns = pd.MultiIndex.from_tuples(precols + samplecols, names=["sample_name"] + model["annotation_cols"])

# sort by annotation columns
samplecols = counts.iloc[:, 3:].sort_values(by=model["annotation_cols"], axis="columns").columns
counts = counts[counts.columns[:3].tolist() + samplecols.tolist()]

counts.to_csv(snakemake.output[0], sep="\t", index=False)