import sys

sys.stderr = open(snakemake.log[0], "w")

import altair as alt
import pandas as pd

counts_and_normalized = pd.read_csv(
    snakemake.input[0],
    sep="\t",
    dtype={
        "type": str,
        "name": str,
        "accession": str,
        "sample": str,
        "count_type": str,
        "expression": float,
    }
)

housekeeping = counts_and_normalized[counts_and_normalized["type"] == "Housekeeping"]
positive = counts_and_normalized[counts_and_normalized["type"] == "Positive"]
negative = counts_and_normalized[counts_and_normalized["type"] == "Negative"]

count_type_order = ["raw", "normalized"]

def chart(gene_set: pd.DataFrame) -> alt.Chart:
    spec = alt.Chart(
            gene_set
        ).encode(
            x="expression:Q",
            y='name:N',
            yOffset=alt.YOffset('count_type:N', sort=count_type_order),
            tooltip=['name', 'accession', 'type', 'count_type', 'expression'],
        )

    return alt.layer(
        spec.mark_boxplot().encode(
            color=alt.Color('count_type:N', sort=count_type_order, scale=alt.Scale(scheme='set2')),
        ),
        spec.mark_point().encode(
            shape='sample:N',
        ).interactive(),
        title=gene_set["type"].iloc[0],
    )

plot = chart(housekeeping) | chart(positive) | chart(negative)

plot.save(snakemake.output[0])
