import sys

sys.stderr = open(snakemake.log[0], "w")

import altair as alt
import pandas as pd

mds = pd.read_csv(snakemake.input["mds"], sep="\t", index_col="sample")
annotation = pd.read_csv(snakemake.input["ann"], sep=",", index_col="sample_name")

# only plot columns with at least two unique values, skip rcc file column
ann_cols = [name for name, col in annotation.items() if name != "rcc" and col.nunique() > 1]

data = pd.concat([mds, annotation], axis="columns")

base = alt.Chart().mark_point().encode(
    x="x:Q",
    y="y:Q",
    tooltip=ann_cols,
).interactive()

chart = alt.vconcat(data=data).resolve_scale(color="independent")
for col in ann_cols:
    chart &= base.encode(color=col)

chart.save(snakemake.output[0])