import sys

sys.stderr = open(snakemake.log[0], "w")

import pandas as pd
from scipy.stats import pearsonr
import altair as alt

model = snakemake.params.model
gene_a = snakemake.wildcards.gene_a
gene_b = snakemake.wildcards.gene_b

ann = pd.read_csv(snakemake.input.ann, index_col="sample_name", dtype=str)

counts = pd.read_csv(snakemake.input[0], sep="\t", index_col=[0,1,2])
counts.index = counts.index.droplevel(["accession", "type"])

counts = counts.loc[[gene_a, gene_b]].T
counts = pd.concat([counts, ann], axis="columns")

corr, pval = pearsonr(counts[gene_a], counts[gene_b])

plt = alt.Chart(counts.reset_index()).mark_point(tooltip=alt.Tooltip(content="data")).encode(
    x=gene_a,
    y=gene_b,
)

text = alt.Chart({"values":[{}]}).mark_text(
    align="left", baseline="top"
).encode(
    x=alt.value(5),  # pixels from left
    y=alt.value(5),  # pixels from top
    text=alt.value([f"r: {corr:.3g}", f"p: {pval:.3g}"]))

(plt + text).save(snakemake.output[0])